timeintervaltools.scale_aggregate_duration_to_rational
======================================================

.. autofunction:: abjad.tools.timeintervaltools.scale_aggregate_duration_to_rational.scale_aggregate_duration_to_rational
